==> libro_ai-0.1.10-py3-none-any.whl: libro_ai/chat/__init__.py <==
from .qwen_chat_provider import TongyiChatObjectProvider
from .debug_provider import DebugChatObjectProvider
from .executor import LLMChat, ChatExecutor
from .openai_chat_provider import OpenAIChatObjectProvider
from .object_manager import ChatObjectManager
from .source import CHAT_SOURCE
from .object import ChatObject, ChatObjectProvider
from .langchain_variable import LangChainVariableChatObjectProvider
from .chat_record import ChatMessage, ChatRecord, ChatRecordProvider
from libro_core.config import libro_config

chat_object_manager = ChatObjectManager()
libro_ai_config = libro_config.get_config().get("llm")
model_type = []
api_key:str = None
if libro_ai_config is not None:
    if tongyi_api_key := libro_ai_config.get("DASHSCOPE_API_KEY"):
        api_key = tongyi_api_key
        chat_object_manager.register_provider(TongyiChatObjectProvider(api_key = api_key))
        model_type.append('tongyi')
    if openai_api_key := libro_ai_config.get("OPENAI_API_KEY"):
        api_key = openai_api_key
        chat_object_manager.register_provider(OpenAIChatObjectProvider(api_key = api_key))
        model_type.append('openai')
chat_object_manager.register_provider(LangChainVariableChatObjectProvider())
chat_object_manager.register_provider(DebugChatObjectProvider(model_type = model_type,api_key = api_key))

chat_record_provider = ChatRecordProvider()

__all__ = [
    "LLMChat",
    "ChatExecutor",
    "chat_object_manager",
    "chat_record_provider",
    "ChatObject",
    "ChatObjectProvider",
    "ChatMessage",
    "ChatRecord",
    "ChatRecordProvider",
    "CHAT_SOURCE",
]

==> libro_ai-0.1.13-py3-none-any.whl: libro_ai/chat/__init__.py <==
from .qwen_chat_provider import TongyiChatObjectProvider
from .debug_provider import DebugChatObjectProvider
from .executor import LLMChat, ChatExecutor
from .openai_chat_provider import OpenAIChatObjectProvider
from .object_manager import ChatObjectManager
from .source import CHAT_SOURCE
from .object import ChatObject, ChatObjectProvider
from .langchain_variable import LangChainVariableChatObjectProvider
from .chat_record import ChatMessage, ChatRecord, ChatRecordProvider
from libro_core.config import libro_config

chat_object_manager = ChatObjectManager()
libro_ai_config = libro_config.get_config().get("llm")
type_of_model = []
api_key:str = None
if libro_ai_config is not None:
    if tongyi_api_key := libro_ai_config.get("DASHSCOPE_API_KEY"):
        api_key = tongyi_api_key
        chat_object_manager.register_provider(TongyiChatObjectProvider(api_key = api_key))
        type_of_model.append('tongyi')
    if openai_api_key := libro_ai_config.get("OPENAI_API_KEY"):
        api_key = openai_api_key
        chat_object_manager.register_provider(OpenAIChatObjectProvider(api_key = api_key))
        type_of_model.append('openai')
chat_object_manager.register_provider(LangChainVariableChatObjectProvider())
chat_object_manager.register_provider(DebugChatObjectProvider(type_of_model = type_of_model,api_key = api_key))

chat_record_provider = ChatRecordProvider()

__all__ = [
    "LLMChat",
    "ChatExecutor",
    "chat_object_manager",
    "chat_record_provider",
    "ChatObject",
    "ChatObjectProvider",
    "ChatMessage",
    "ChatRecord",
    "ChatRecordProvider",
    "CHAT_SOURCE",
]
